package com.gyee.datacenter.controller;

import com.gyee.datacenter.common.StringUtils;
import com.gyee.datacenter.config.R;
import com.gyee.datacenter.model.PointDataVo;
import com.gyee.datacenter.model.auto.Datacenter;
import com.gyee.datacenter.model.auto.Datacenterpoint;
import com.gyee.datacenter.model.export.RealExport;
import com.gyee.datacenter.service.OutputService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;

/**
 * @ClassName : OutputController
 * @Author : xieshengjie
 * @Date: 2021/5/13 15:37
 * @Description : 对外接口
 */
@RestController
@RequestMapping("//datacenter")
public class OutputController {
    @Autowired
    private OutputService outputService;

    /**
     * 获取所有表名
     * @return
     */
    @GetMapping("/tables")
    @ResponseBody
    @CrossOrigin(origins = "*", maxAge = 3600)
    public R getTables(){
        List<Datacenter> tables = outputService.getTables();
        if (StringUtils.isNotNull(tables)) {
            return R.ok().data(tables);
        }else{
            return R.error().message("访问失败");
        }
    }

    /**
     * 根据表名点名查询数据
     * @param tableid
     * @param pointId
     * @return
     */
    @GetMapping("/realtimeData")
    @ResponseBody
    @CrossOrigin(origins = "*", maxAge = 3600)
    public R getRealtimedata(@RequestParam(value = "tableid",required = true)String tableid,
                               @RequestParam(value = "pointId",required = false)String pointId,
                               @RequestParam(value = "pointName",required = false)String pointName,
                             @RequestParam(value = "pageNum",required = true)String pageNum,
                             @RequestParam(value = "pageSize",required = true)String pageSize) {
        List<Datacenterpoint> realtimeList = outputService.getRealtimeList(tableid, pointId, pointName);
        List<PointDataVo> vos = null;
        long count =0;
        if(StringUtils.isNotNull(realtimeList)){
            count = realtimeList.size();
            vos = outputService.getRealtimedata(realtimeList,pageNum,pageSize);
        }
        if (StringUtils.isNotNull(vos)) {
            return R.ok(count).data(vos);
        }else {
            return R.error().data("访问失败");
        }
    }

    /**
     * 根据点名查询历史数据
     * @param pointId
     * @param begin
     * @param end
     * @param interval
     * @return
     */
    @GetMapping("/historyData")
    @ResponseBody
    @CrossOrigin(origins = "*", maxAge = 3600)
    public R gethistoryData(@RequestParam(value = "pointId",required = true)String pointId,
                                     @RequestParam(value = "begin",required = true)String begin,
                                     @RequestParam(value = "end",required = true)String end,
                                     @RequestParam(value = "interval",required = false)String interval,
                             @RequestParam(value = "type",required = false)String type) {
        List<PointDataVo> vos = outputService.gethistoryData(pointId,begin,end,interval,type);
        if (StringUtils.isNotNull(vos)) {
            return R.ok().data(vos);
        }else {
            return R.error().message("访问失败");
        }
    }

    @GetMapping("/realtimeExport")
    @ResponseBody
    @CrossOrigin(origins = "*", maxAge = 3600)
    public R realtimeExport(@RequestParam(value = "tableid",required = true)String tableid,
                               @RequestParam(value = "pointId",required = false)String pointId,
                               @RequestParam(value = "pointName",required = false)String pointName,HttpServletResponse response) throws IOException {

        List<RealExport> list = outputService.getRealtimeExport(tableid,pointId,pointName);
        if (StringUtils.isNotNull(list)) {
            return R.ok().data(list);
        }else {
            return R.error().data("访问失败");
        }
    }

}
