package com.gyee.datacenter.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.gyee.datacenter.common.StringUtils;
import com.gyee.datacenter.config.R;
import com.gyee.datacenter.init.CacheContext;
import com.gyee.datacenter.model.auto.Uniformcode;
import com.gyee.datacenter.model.auto.Windturbine;
import com.gyee.datacenter.service.ParameterComparisonService;
import com.gyee.datacenter.service.auto.IWindturbineService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.stream.Collectors;

/**
 * @ClassName : ParameterComparisonController
 * @Author : xieshengjie
 * @Date: 2021/5/25 9:05
 * @Description : 参数对比controller
 */
@RestController
@RequestMapping("//paramComparison")
public class ParameterComparisonController {
    @Autowired
    private IWindturbineService windturbineService;
    @Autowired
    private ParameterComparisonService parameterComparisonService;


    /**
     * 获取设备结构
     * @return
     */
    @GetMapping("/equipmentStructure")
    @ResponseBody
    @CrossOrigin(origins = "*", maxAge = 3600)
    public R getEquipmentStructure(@RequestParam(value = "wtid",required = false)String wtid){
        QueryWrapper<Windturbine> qw = new QueryWrapper<>();
        if (StringUtils.isNotNull(wtid)){
            qw.like("id",wtid);
        }
        qw.like("windpowerstationid","FDC");
        List<Windturbine> wts = windturbineService.list(qw);
        if (StringUtils.isNotNull(wts)) {
            return R.ok().data(wts);
        }else{
            return R.error().message("访问失败");
        }
    }

    /**
     * 获取参数列表
     * @return
     */
    @GetMapping("/equipmentParams")
    @ResponseBody
    @CrossOrigin(origins = "*", maxAge = 3600)
    public R getEquipmentParams(@RequestParam(value = "description",required = false)String description){
        List<Uniformcode> codeList = CacheContext.codeList;
        if (StringUtils.isNotNull(description)){
            codeList = codeList.stream().filter(i->i.getDescription().contains(description)).collect(Collectors.toList());
        }
        if (StringUtils.isNotNull(codeList)) {
            return R.ok().data(codeList);
        }else{
            return R.error().message("访问失败");
        }
    }


    /**
     * 生成曲线
     * @return
     */
    @GetMapping("/generatingCurve")
    @ResponseBody
    @CrossOrigin(origins = "*", maxAge = 3600)
    public R generatingCurve(@RequestParam(value = "begin",required = true)String begin,
                                @RequestParam(value = "end",required = true)String end,
                                @RequestParam(value = "interval",required = false)String interval,
                                @RequestParam(value = "type",required = false)String type,
                             @RequestParam(value = "paramtype",required = true)String paramtype,
                                @RequestParam(value = "wts",required = true)String wts,
                                @RequestParam(value = "params",required = true)String params) throws Exception {
//        Map<String, List<ParameterComparisonVo>> stringListMap = null;
        List<Object> result = null;
        if (paramtype.equals("1")){//单风机
            result = parameterComparisonService.generatingCurveBywt(begin, end, interval, type, wts, params);
        }else {
            result = parameterComparisonService.generatingCurveByParam(begin,end,interval,type,wts,params);
        }
        if (StringUtils.isNotNull(result)) {
            return R.ok().data(result);
        }else{
            return R.error().message("访问失败");
        }
    }
}
