package com.gyee.datacenter.service;

import com.gyee.datacenter.common.PointData;
import com.gyee.datacenter.common.StringUtils;
import com.gyee.datacenter.init.CacheContext;
import com.gyee.datacenter.model.PointDataVo;
import com.gyee.datacenter.model.auto.Datacenter;
import com.gyee.datacenter.model.auto.Datacenterpoint;
import com.gyee.datacenter.model.export.RealExport;
import com.gyee.datacenter.service.auto.IDatacenterService;
import com.gyee.datacenter.service.auto.IDatacenterpointService;
import com.gyee.datacenter.util.DateUtils;
import com.gyee.datacenter.util.PageUtil;
import com.gyee.datacenter.util.golden.EdosUtil;
import com.gyee.datacenter.util.golden.IEdosUtil;
import com.gyee.datacenter.util.redis.RedisService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @ClassName : OutputService
 * @Author : xieshengjie
 * @Date: 2021/5/13 15:40
 * @Description : 对外service
 */
@Service
public class OutputService {

    private IEdosUtil edosUtil = new EdosUtil();
    @Autowired
    private IDatacenterService datacenterService;
    @Autowired
    private IDatacenterpointService datacenterpointService;
    @Autowired
    private RedisService redisService;



    public List<Datacenter> getTables() {
        return CacheContext.tableList;
    }

    public List<PointDataVo> gethistoryData(String pointId, String begin, String end, String interval,String type) {

        List<PointDataVo> resultList = new ArrayList<>();
        Date beginDate = DateUtils.parseDate1(begin);
        Date endDate = DateUtils.parseDate1(end);
        List<PointData> pointDatas = null;

        try {
            if (interval != null) {
                if (type!=null){
                    pointDatas = edosUtil.getHistStat(pointId,beginDate.getTime()/1000, endDate.getTime()/1000,null,Long.parseLong(interval),Integer.parseInt(type));
                }else{
                    pointDatas = edosUtil.getHistoryDatasSnap(pointId,beginDate.getTime()/1000, endDate.getTime()/1000,null,Long.parseLong(interval));
                }
//                pointDatas = edosUtil.getHistoryDatasSnap(pointId,beginDate.getTime()/1000, endDate.getTime()/1000,null,Long.parseLong(interval));
//                pointDatas = PageUtil.startPage(pointDatas,Integer.parseInt(pageNum),Integer.parseInt(pageSize));
            }else {
                pointDatas = edosUtil.getHistoryDatasRaw(pointId, beginDate.getTime()/1000, endDate.getTime()/1000);
//                pointDatas = PageUtil.startPage(edosUtil.getHistoryDatasRaw(pointId, beginDate.getTime()/1000, endDate.getTime()/1000),Integer.parseInt(pageNum),Integer.parseInt(pageSize));
            }
        }catch (Exception e) {
            e.printStackTrace();
        }
        if (StringUtils.isNotEmpty(pointDatas)){
            pointDatas.stream().forEach(pointData->{
                PointDataVo vo = new PointDataVo();
                vo.setPointId(pointData.getEdnaId());
                vo.setPointName(CacheContext.inmap.get(vo.getPointId()));
                vo.setValue(pointData.getPointValueInDouble());
                vo.setTime(DateUtils.parseLongToDate(pointData.getPointTime()*1000));
                resultList.add(vo);
            });
        }
        return resultList;
    }

    public List<PointDataVo> getRealtimedata(List<Datacenterpoint> realtimedataList,String pageNum,String pageSize) {

        List<PointDataVo> resultList = new ArrayList<>();
        realtimedataList = PageUtil.startPage(realtimedataList,Integer.parseInt(pageNum),Integer.parseInt(pageSize));
//        realtimedataList = realtimedataList.stream().limit(200).collect(Collectors.toList());
        List<String> pointIdList = realtimedataList.stream().map(i -> i.getId()).collect(Collectors.toList());

        List<PointData> realDatas = null;
        try {
            if (StringUtils.isNotEmpty(pointIdList)){
                realDatas  = edosUtil.getRealData(pointIdList);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        if (StringUtils.isNotEmpty(realDatas)) {
            realDatas.stream().filter(pointData -> pointData.getPointTime()!=null).forEach(pointData -> {
                PointDataVo vo = new PointDataVo();
                vo.setPointId(pointData.getEdnaId());
                vo.setPointName(CacheContext.inmap.get(vo.getPointId()));
                vo.setValue(pointData.getPointValueInDouble());
                vo.setTime(DateUtils.parseLongToDate(pointData.getPointTime()));
                resultList.add(vo);
            });
        }
        return resultList;
    }

    public List<Datacenterpoint> getRealtimeList(String tableid, String pointId, String pointName) {
        Map<String, List<Datacenterpoint>> pointmap = CacheContext.pointmap;
        List<Datacenterpoint> realtimedataList = pointmap.get(tableid);
        if (StringUtils.isNotEmpty(pointId)) {
            realtimedataList = realtimedataList.stream().filter(i -> i.getId().contains(pointId)).collect(Collectors.toList());
        }
        if (StringUtils.isNotEmpty(pointName)) {
            realtimedataList = realtimedataList.stream().filter(i -> i.getName().contains(pointName)).collect(Collectors.toList());
        }
        return realtimedataList;
    }

    public List<RealExport> getRealtimeExport(String tableid, String pointId, String pointName) {
        List<RealExport> resultList = new ArrayList<>();

        List<Datacenterpoint> realtimedataList = getRealtimeList(tableid, pointId, pointName);
        realtimedataList.stream().forEach(i->{
            RealExport re = new RealExport();
            re.setId(i.getId());
            re.setName(i.getName());
            resultList.add(re);
        });
        return resultList;
    }
}
